CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
156 lines
4.6 KiB
C++
156 lines
4.6 KiB
C++
/* ************************************************************************
|
|
* Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
|
|
*
|
|
* Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
* of this software and associated documentation files (the "Software"), to deal
|
|
* in the Software without restriction, including without limitation the rights
|
|
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell cop-
|
|
* ies of the Software, and to permit persons to whom the Software is furnished
|
|
* to do so, subject to the following conditions:
|
|
*
|
|
* The above copyright notice and this permission notice shall be included in all
|
|
* copies or substantial portions of the Software.
|
|
*
|
|
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IM-
|
|
* PLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
|
|
* FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
|
|
* COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
|
|
* IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNE-
|
|
* CTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
|
|
*
|
|
*
|
|
* ************************************************************************ */
|
|
#pragma once
|
|
|
|
#include "d_vector.hpp"
|
|
|
|
#include "device_batch_vector.hpp"
|
|
#include "device_strided_batch_vector.hpp"
|
|
|
|
#include "host_batch_vector.hpp"
|
|
#include "host_strided_batch_vector.hpp"
|
|
|
|
//!
|
|
//! @brief Random number with type deductions.
|
|
//!
|
|
template <typename T>
|
|
void random_generator(T& n)
|
|
{
|
|
n = random_generator<T>();
|
|
}
|
|
|
|
//!
|
|
//!
|
|
//!
|
|
template <typename T>
|
|
void random_nan_generator(T& n)
|
|
{
|
|
n = T(hipsolver_nan_rng());
|
|
}
|
|
|
|
//!
|
|
//! @brief Template for initializing a host
|
|
//! (non_batched|batched|strided_batched)vector.
|
|
//! @param that That vector.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename U>
|
|
void rocblas_init_template(U& that, bool seedReset = false)
|
|
{
|
|
if(seedReset)
|
|
{
|
|
hipsolver_seedrand();
|
|
}
|
|
|
|
for(rocblas_int batch_index = 0; batch_index < that.batch_count(); ++batch_index)
|
|
{
|
|
auto batched_data = that[batch_index];
|
|
auto inc = std::abs(that.inc());
|
|
auto n = that.n();
|
|
if(inc < 0)
|
|
{
|
|
batched_data -= (n - 1) * inc;
|
|
}
|
|
|
|
for(rocblas_int i = 0; i < n; ++i)
|
|
{
|
|
random_generator(batched_data[i * inc]);
|
|
}
|
|
}
|
|
}
|
|
|
|
//!
|
|
//! @brief Template for initializing a host
|
|
//! (non_batched|batched|strided_batched)vector with NaNs.
|
|
//! @param that That vector.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename U>
|
|
void rocblas_init_nan_template(U& that, bool seedReset = false)
|
|
{
|
|
if(seedReset)
|
|
{
|
|
hipsolver_seedrand();
|
|
}
|
|
|
|
for(rocblas_int batch_index = 0; batch_index < that.batch_count(); ++batch_index)
|
|
{
|
|
auto batched_data = that[batch_index];
|
|
auto inc = std::abs(that.inc());
|
|
auto n = that.n();
|
|
if(inc < 0)
|
|
{
|
|
batched_data -= (n - 1) * inc;
|
|
}
|
|
|
|
for(rocblas_int i = 0; i < n; ++i)
|
|
{
|
|
random_nan_generator(batched_data[i * inc]);
|
|
}
|
|
}
|
|
}
|
|
|
|
//!
|
|
//! @brief Initialize a host_strided_batch_vector.
|
|
//! @param that The host strided batch vector.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename T>
|
|
void rocblas_init(host_strided_batch_vector<T>& that, bool seedReset = false)
|
|
{
|
|
rocblas_init_template(that, seedReset);
|
|
}
|
|
|
|
//!
|
|
//! @brief Initialize a host_batch_vector.
|
|
//! @param that The host batch vector.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename T>
|
|
void rocblas_init(host_batch_vector<T>& that, bool seedReset = false)
|
|
{
|
|
rocblas_init_template(that, seedReset);
|
|
}
|
|
|
|
//!
|
|
//! @brief Initialize a host_strided_batch_vector with NaNs.
|
|
//! @param that The host strided batch vector to be initialized.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename T>
|
|
void rocblas_init_nan(host_strided_batch_vector<T>& that, bool seedReset = false)
|
|
{
|
|
rocblas_init_nan_template(that, seedReset);
|
|
}
|
|
|
|
//!
|
|
//! @brief Initialize a host_strided_batch_vector with NaNs.
|
|
//! @param that The host strided batch vector to be initialized.
|
|
//! @param seedReset reset the seed if true, do not reset the seed otherwise.
|
|
//!
|
|
template <typename T>
|
|
void rocblas_init_nan(host_batch_vector<T>& that, bool seedReset = false)
|
|
{
|
|
rocblas_init_nan_template(that, seedReset);
|
|
}
|